<?php
/**
 * Awesomesauce class.
 * @category   Class
 */

namespace ElementorMiraculous;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */
class Miraculous_track extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Track';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Track', 'miraculous' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-parallax';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'miraculous-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $options = array();
		$this->start_controls_section(
            'heading',
            [
                'label' => esc_html__( 'Track', 'miraculous' ),
            ]
        );
        $this->add_control(
            'track_heading',
            [
                'label'       => esc_html__( 'Track Heading', 'miraculous' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'miraculous' ),
            ]
        );
        $this->add_control(
			'style_format',
			[
				'label' => esc_html__( 'Style format', 'miraculous' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'abstyle1',
				'options' => [
					'abstyle1' => esc_html__( 'Slider', 'miraculous' ),
					'abstyle2' => esc_html__( 'Weekly', 'miraculous' ),
					'abstyle3' => esc_html__( 'Grid', 'miraculous' ),
					'abstyle4' => esc_html__( 'Slider 2', 'miraculous' ),
					'abstyle5' => esc_html__( 'List', 'miraculous' ),
				],
			]
		);
		$this->add_control(
			'track',
			[
				'label' => esc_html__( 'Track', 'miraculous' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all' => esc_html__( 'All', 'miraculous' ),
					'free'  => esc_html__( 'Free', 'miraculous' ),
					'premium' => esc_html__( 'Premium', 'miraculous' ),
				],
			]
		);
		$this->add_control(
			'track_filter',
			[
				'label' => esc_html__( 'Songs Filter By', 'miraculous' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'select' => esc_html__( 'Select', 'miraculous' ),
					'song_views_count'  => esc_html__( 'Song View', 'miraculous' ),
					'song_dowenload_counter' => esc_html__( 'Song Download', 'miraculous' ),
				],
			]
		);
		$this->add_control(
			'track_type',
			[
				'label' => __( 'Track Type', 'miraculous' ),
                'label_block' => ('bool'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => get_custom_type_category('music-type')
			]
		);
        $this->add_control(
            'track_number',
            [
                'label'       => esc_html__( 'Number of Track', 'miraculous' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'miraculous' ),
            ]
        );
        $this->add_control(
			'song_view',
			[
				'label' => esc_html__( 'Song View Counter', 'miraculous' ),
				'type' => Controls_Manager::SWITCHER,
				'no' => esc_html__( 'No', 'miraculous' ),
				'yes' => esc_html__( 'Yes', 'miraculous' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'song_download',
			[
				'label' => esc_html__( 'Song View Dowenload', 'miraculous' ),
				'type' => Controls_Manager::SWITCHER,
				'no' => esc_html__( 'No', 'miraculous' ),
				'yes' => esc_html__( 'Yes', 'miraculous' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
        $list_type = 'music';
        $more_img = get_template_directory_uri().'/assets/images/svg/more.svg';
        $play_img = get_template_directory_uri().'/assets/images/svg/play.svg';
        
        if(!empty($settings['track_type'])){
    		$music_cats = get_terms('music-type');
    		foreach($music_cats as $cats){
                $onecat = $cats->term_id;
                $alcat[] = $cats->term_id;
                if(in_array($onecat, $settings['track_type'])){
                    $data[] = 'true';
                }else{
                    $data[] = 'false';
                }
            }
            $inarr = in_array("true", $data);
            if($inarr != '1'){
                $settings['track_type'] = $alcat;
            }
        }
		if( defined('FW') ){
			$miraculous_theme_data = '';
			if (function_exists('fw_get_db_settings_option')):  
			  $miraculous_theme_data = fw_get_db_settings_option();     
			endif; 
			$currency = '';
			if(!empty($miraculous_theme_data['paypal_currency']) && function_exists('miraculous_currency_symbol')):
				$currency = miraculous_currency_symbol( $miraculous_theme_data['paypal_currency'] );
			endif;
			
			$musictype_key = 'fw_option:music_types';
		}
		
		//Redux Option
		if ( class_exists( 'ReduxFramework' ) ) {
			$miraculous_theme_data = '';
			$miraculous_theme_data = get_option('miraculous_options');
			
			$currency = '';
			if(!empty($miraculous_theme_data['currency']) && function_exists('miraculous_currency_symbol')):
				$currency = miraculous_currency_symbol( $miraculous_theme_data['currency'] );
			endif;
			
			$musictype_key = 'music_types';
		}
        $user_id = get_current_user_id();
        $lang_data = get_option('language_filter_ids_'.$user_id);
        
        $fav_music_ids = '';
        if($user_id){
            $fav_music_ids = get_user_meta($user_id, 'favourites_songs_lists'.$user_id, true);
        }
        if($settings['track'] == 'all'){
            $track_type =  array ( 'free', 'premium' );
        }
        else{
            $track_type = $settings['track'];
        }
		
		
        if( is_user_logged_in() && $lang_data ){
            $sg_args = array('post_type' => 'ms-music',
                        'posts_per_page' => $settings['track_number'],
                        'meta_query' => array(
                            'relation' => 'OR',
                            'music_types' => array(
                        		'key' => $musictype_key,
                        		'value' => $track_type
                        	),
                        	'music_filter' => array(
                        		'key' => $settings['track_filter'],
                        		'type' => 'NUMERIC',
                        	)
                        ),
                        'orderby' => array(
        		            'music_filter' => 'DESC',
        	            ),
                        'tax_query' => array(
                                array(
                                    'taxonomy' => 'music-type',
                                    'terms' => $settings['track_type']
                                ),
                                array(
                                    'taxonomy' => 'language',
                                    'terms' => $lang_data
                                )
                            )
                        );
        }elseif ( isset($_COOKIE['lang_filter']) ) {
             $lang_data = explode(',', $_COOKIE['lang_filter']);
             $sg_args = array('post_type' => 'ms-music',
                        'posts_per_page' => $settings['track_number'],
                        'meta_query' => array(
                            'relation' => 'OR',
                            'music_types' => array(
                        		'key' => $musictype_key,
                        		'value' => $track_type
                        	),
                        	'music_filter' => array(
                        		'key' => $settings['track_filter'],
                        		'type' => 'NUMERIC',
                        	)
                        ),
                        'orderby' => array(
        		            'music_filter' => 'DESC',
        	            ),
                        'tax_query' => array(
                                array(
                                    'taxonomy' => 'music-type',
                                    'terms' => $settings['track_type']
                                ),
                                array(
                                    'taxonomy' => 'language',
                                    'terms' => $lang_data
                                )
                            )
                        );
        }else{
            $sg_args = array('post_type' => 'ms-music',
                        'posts_per_page' => $settings['track_number'],
                        'meta_query' => array(
                            'relation' => 'OR',
                            'music_types' => array(
                        		'key' => $musictype_key,
                        		'value' => $track_type
                        	),
                        	'music_filter' => array(
                        		'key' => $settings['track_filter'],
                        		'type' => 'NUMERIC',
                        	)
                        ),
                        'orderby' => array(
        		            'music_filter' => 'DESC',
        	            ),
                        'tax_query' => array(
                                array(
                                    'taxonomy' => 'music-type',
                                    'terms' => $settings['track_type']
                                )
                            )
                    );
        }
        // the query
        $music_posts = new \WP_Query( $sg_args );
        
        if( $music_posts->have_posts() ): 
        if( $settings['style_format'] == 'abstyle1' ): ?>
        <div class="ms_fea_album_slider">
            <?php if(!empty($settings['track_heading'])){ ?>
            <div class="ms_heading">
                <h1><?php echo esc_html( $settings['track_heading'] ); ?></h1>
            </div>
            <?php } ?>
            <div class="ms_relative_inner">
                <div class="ms_feature_slider swiper-container swiper-container-horizontal">
                    <div class="swiper-wrapper">
                        <?php
                        $i=0; 
                        while ( $music_posts->have_posts() ) : $music_posts->the_post();
                        ?>
                        <div class="swiper-slide<?php echo ($i==0) ? ' swiper-slide-active' : '';?>" data-swiper-slide-index="<?php echo _e($i); ?>">
                                <div class="ms_rcnt_box">
                                    <div class="ms_rcnt_box_img">
                                        <?php the_post_thumbnail( 'large' ); ?>
                                        <div class="ms_main_overlay">
                                            <div class="ms_box_overlay"></div>
                                            <div class="ms_more_icon">
                                                <img src="<?php echo esc_url($more_img); ?>" alt="<?php echo esc_attr('More', 'miraculous'); ?>">
                                            </div>
                                            <?php $attach_meta = array();
												if( defined('FW') ){
													$music_extranal_url = get_post_meta(get_the_id(), 'fw_option:music_extranal_url', true);
													if(!empty($music_extranal_url)):
													   $mpurl = $music_extranal_url;
													else:
													   $mpurl = get_post_meta(get_the_id(), 'fw_option:mp3_full_songs', true);
													endif;
												}
												
												if ( class_exists( 'ReduxFramework' ) ) {
													$music_extranal_url = get_post_meta(get_the_id(),'music_extranal_url',true);
													if(!empty($music_extranal_url)):
														$mpurl = $music_extranal_url;
													else:
														$mpurl = get_post_meta(get_the_id(), 'mp3_full_songs', true);
													endif;
												}
												
                                                $image_uri = get_the_post_thumbnail_url ( get_the_id() );
                                                $fav_class = 'icon_fav';
                                                if(!empty($fav_music_ids)){
                                                    if( in_array(get_the_id(), $fav_music_ids) ) {
                        			                    $fav_class = 'icon_fav_add';
                        		      	            }
                                                } ?>
                                            <ul class="more_option">
                                                <li><a href="javascript:;" class="favourite_music" data-musicid="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon <?php echo esc_attr($fav_class); ?>">
        											<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_08-5" data-name=" 08-5"><path id="_08-6" data-name=" 08-6" class="cls-1" d="M13.7,4.49a4.34,4.34,0,0,0-2,.48,3.83,3.83,0,0,0-.73.48A3.54,3.54,0,0,0,10.27,5,4.3,4.3,0,0,0,4,8.83a7.6,7.6,0,0,0,2.46,5.05,22.38,22.38,0,0,0,4,3.29l.51.34.52-.34a23.09,23.09,0,0,0,4-3.29A7.63,7.63,0,0,0,18,8.83,4.34,4.34,0,0,0,13.7,4.49ZM8.31,6.36a2.42,2.42,0,0,1,1.94,1l.75,1,.76-1a2.39,2.39,0,0,1,1.94-1,2.45,2.45,0,0,1,2.43,2.47,5.89,5.89,0,0,1-1.95,3.78A20.15,20.15,0,0,1,11,15.26a20.07,20.07,0,0,1-3.17-2.65A5.89,5.89,0,0,1,5.88,8.83,2.45,2.45,0,0,1,8.31,6.36Z"/></g></svg>
        										</span></span><?php esc_html_e('Favourites', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="add_to_queue" data-musicid="<?php esc_attr_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>"><span class="opt_icon"><span class="icon icon_queue">
        											<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
        													<path fill-rule="evenodd" d="M11.359,5.172 L6.847,5.172 L6.847,0.660 C6.847,0.455 6.568,0.009 6.010,0.009 C5.452,0.009 5.172,0.455 5.172,0.660 L5.172,5.172 L0.661,5.172 C0.455,5.172 0.010,5.451 0.010,6.009 C0.010,6.567 0.455,6.846 0.661,6.846 L5.173,6.846 L5.173,11.358 C5.173,11.563 5.452,12.009 6.010,12.009 C6.568,12.009 6.847,11.563 6.847,11.358 L6.847,6.846 L11.359,6.846 C11.564,6.846 12.010,6.567 12.010,6.009 C12.010,5.451 11.564,5.172 11.359,5.172 Z"/>
        													</svg>
        										</span></span><?php esc_html_e('Add To Queue', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="ms_download" data-msmusic="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon icon_dwn">
        											<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_06-4" data-name=" 06-4"><path id="_06-5" data-name=" 06-5" class="cls-1" d="M10.65,13.85a.48.48,0,0,0,.7,0l3.27-3.5a.41.41,0,0,0,.07-.47.48.48,0,0,0-.42-.26H12.4V4.94a.46.46,0,0,0-.47-.44H10.07a.46.46,0,0,0-.47.44V9.63H7.73a.44.44,0,0,0-.42.25.41.41,0,0,0,.07.47Zm5.48-.73v2.63H5.87V13.12H4v3.5a.9.9,0,0,0,.93.88H17.07a.9.9,0,0,0,.93-.88v-3.5Z"/></g></svg>
        										</span></span><?php esc_html_e('Download Now', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="ms_add_playlist" data-msmusic="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon icon_playlst">
        											<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_03-2" data-name=" 03-2"><path id="_03-3" data-name=" 03-3" class="cls-1" d="M13,5.5H3.5V7.07H13V5.5Zm0,3.14H3.5v1.57H13V8.64ZM3.5,13.36H9.82V11.79H3.5ZM14.55,5.5v6.43a2.35,2.35,0,1,0,1.58,2.21V7.07H18.5V5.5Z"/></g></svg>
        										</span></span><?php esc_html_e('Add To Playlist', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="ms_share_music" data-shareuri="<?php esc_attr_e(get_the_permalink()); ?>" data-sharename="<?php the_title_attribute(); ?>"><span class="opt_icon"><span class="icon icon_share">
        											<svg xmlns="http://www.w3.org/2000/svg" id="Layer_1" data-name="Layer 1" viewBox="0 0 22 22"><g id="_14-2" data-name=" 14-2"><path id="_13" data-name=" 13" class="cls-1" d="M8.68,13.18A2.78,2.78,0,0,1,4.77,13l-.07-.08a3,3,0,0,1,0-3.85,2.77,2.77,0,0,1,3.89-.36.52.52,0,0,1,.11.1l3-2.11.09-.06a1.09,1.09,0,0,0,.63-1.08A2.76,2.76,0,0,1,15.05,3,2.84,2.84,0,0,1,17.9,5.22a3,3,0,0,1-1.36,3.22,2.72,2.72,0,0,1-3.34-.5l-.27-.3C11.81,8.41,10.7,9.18,9.6,10a.37.37,0,0,0-.09.28q0,.75,0,1.5a.51.51,0,0,0,.13.34c1.08.77,2.18,1.52,3.3,2.3a2.89,2.89,0,0,1,1.76-1.15A2.83,2.83,0,0,1,18,15.56h0A2.92,2.92,0,0,1,15.72,19a2.82,2.82,0,0,1-3.28-2.28,3.33,3.33,0,0,1,0-.63.55.55,0,0,0-.16-.38ZM6.82,9.55a1.45,1.45,0,0,0,0,2.9,1.45,1.45,0,0,0,0-2.9ZM15.2,7.36a1.43,1.43,0,0,0,1.39-1.45h0A1.4,1.4,0,1,0,15.2,7.36Zm0,7.29a1.42,1.42,0,0,0-1.4,1.43h0a1.4,1.4,0,0,0,1.44,1.36,1.4,1.4,0,0,0,0-2.8Z"/></g></svg>
        										</span></span><?php esc_html_e('Share', 'miraculous'); ?></a></li>
                                            </ul>
                                            <div class="ms_play_icon play_btn play_music" data-musicid="<?php esc_attr_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>">
                                                <img src="<?php echo esc_url($play_img); ?>" alt="<?php  esc_attr_e('play', 'miraculous'); ?>">
                                            </div>
                                        </div>
                                    </div>
                                    <div class="ms_rcnt_box_text astha">
                                        <h3><a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a></h3>
                                        <?php $artists_name = array(); 
										if( defined('FW') ){
											$artists_ids = fw_get_db_post_option(get_the_id(), 'music_artists'); 
											
											foreach ($artists_ids as $artists_id) {
												 $artists_name[] = get_the_title($artists_id);
											}
										}
										if ( class_exists( 'ReduxFramework' ) ) {
											$artists_name = array();
											$artists_ids = '';
											$artists_ids = get_post_meta(get_the_id(), 'music_artists');
											if(!empty($artists_ids)){
    											foreach ($artists_ids[0] as $artists_id) {
    											   $artists_name[] = get_the_title($artists_id);
    											}
											}
										} ?>
                                        <p><?php echo implode(', ', $artists_name); ?></p>
                                    </div>
                                </div>
                            </div>
        
                        <?php $i++; endwhile; ?>
                        <?php wp_reset_postdata(); ?>
                    </div>
        
                    <span class="swiper-notification" aria-live="assertive" aria-atomic="true"></span>
                    <span class="swiper-notification" aria-live="assertive" aria-atomic="true"></span>
        
                </div>
                <!-- Add Arrows -->
                <div class="swiper-button-next swiper-button-next-elementor" tabindex="0" role="button" aria-label="<?php esc_attr_e('Next slide','miraculous'); ?>">
            	    <svg xmlns="http://www.w3.org/2000/svg" version="1.1" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" width="512" height="512" x="0" y="0" viewBox="0 0 128 128" style="enable-background:new 0 0 512 512" xml:space="preserve" class=""><g><path xmlns="http://www.w3.org/2000/svg" id="Down_Arrow_3_" d="m64 88c-1.023 0-2.047-.391-2.828-1.172l-40-40c-1.563-1.563-1.563-4.094 0-5.656s4.094-1.563 5.656 0l37.172 37.172 37.172-37.172c1.563-1.563 4.094-1.563 5.656 0s1.563 4.094 0 5.656l-40 40c-.781.781-1.805 1.172-2.828 1.172z" data-original="#000000" class=""></path></g></svg>
            	</div>
            
            	<div class="swiper-button-prev swiper-button-prev-elementor" tabindex="0" role="button" aria-label="<?php esc_attr_e('Previous slide','miraculous'); ?>">
                	<svg xmlns="http://www.w3.org/2000/svg" version="1.1" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" width="512" height="512" x="0" y="0" viewBox="0 0 128 128" style="enable-background:new 0 0 512 512" xml:space="preserve" class=""><g><path xmlns="http://www.w3.org/2000/svg" id="Down_Arrow_3_" d="m64 88c-1.023 0-2.047-.391-2.828-1.172l-40-40c-1.563-1.563-1.563-4.094 0-5.656s4.094-1.563 5.656 0l37.172 37.172 37.172-37.172c1.563-1.563 4.094-1.563 5.656 0s1.563 4.094 0 5.656l-40 40c-.781.781-1.805 1.172-2.828 1.172z" data-original="#000000" class=""></path></g></svg>
            	</div>
            </div>
        </div>
        <?php endif; 
        if( $settings['style_format'] == 'abstyle3' ): ?>
        <!----Top Artist Section---->
        <div class="ms_top_artist">
            <div class="container-fluid">
                <div class="row">
                    <?php if(!empty($settings['track_heading'])){ ?>
                    <div class="col-lg-12">
                        <div class="ms_heading">
                            <h1><?php echo esc_html( $settings['track_heading'] ); ?></h1>
                        </div>
                    </div>
                    <?php } ?>
                    <?php while ( $music_posts->have_posts() ) : $music_posts->the_post(); 
                        ?>
                        <div class="col-lg-2">
                            <div class="ms_rcnt_box marger_bottom30">
                                <div class="ms_rcnt_box_img">
                                    <?php the_post_thumbnail( 'large' ); ?>
                                    <div class="ms_main_overlay">
                                        <div class="ms_box_overlay"></div>
                                        <div class="ms_more_icon">
                                            <img src="<?php echo esc_url($more_img); ?>" alt="<?php echo esc_attr__('More', 'miraculous'); ?>">
                                        </div>
                                        <?php $attach_meta = array();
										
                                            if(function_exists('fw_get_db_post_option')){
												$music_extranal_url = get_post_meta(get_the_id(), 'fw_option:music_extranal_url', true);
												
												if(!empty($music_extranal_url)):
													$mpurl = $music_extranal_url;
												else:
													$mpurl = get_post_meta(get_the_id(), 'fw_option:mp3_full_songs', true);
												endif;
											}

											if ( class_exists( 'ReduxFramework' ) ) {
												$music_extranal_url = get_post_meta(get_the_id(),'music_extranal_url',true);
												if(!empty($music_extranal_url)):
													$mpurl = $music_extranal_url;
												else:
													$mpurl = get_post_meta(get_the_id(), 'mp3_full_songs', true);
												endif;
											}
											
                                            $image_uri = get_the_post_thumbnail_url ( get_the_id() );
                                            $fav_class = 'icon_fav';
                                            if(!empty($fav_music_ids)){
                                                if( in_array(get_the_id(), $fav_music_ids) ) {
                    			                    $fav_class = 'icon_fav_add';
                    		      	            }
                                            } ?>
                                        <ul class="more_option">
                                                <li><a href="javascript:;" class="favourite_music" data-musicid="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon <?php echo esc_attr($fav_class); ?>">
        											<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_08-5" data-name=" 08-5"><path id="_08-6" data-name=" 08-6" class="cls-1" d="M13.7,4.49a4.34,4.34,0,0,0-2,.48,3.83,3.83,0,0,0-.73.48A3.54,3.54,0,0,0,10.27,5,4.3,4.3,0,0,0,4,8.83a7.6,7.6,0,0,0,2.46,5.05,22.38,22.38,0,0,0,4,3.29l.51.34.52-.34a23.09,23.09,0,0,0,4-3.29A7.63,7.63,0,0,0,18,8.83,4.34,4.34,0,0,0,13.7,4.49ZM8.31,6.36a2.42,2.42,0,0,1,1.94,1l.75,1,.76-1a2.39,2.39,0,0,1,1.94-1,2.45,2.45,0,0,1,2.43,2.47,5.89,5.89,0,0,1-1.95,3.78A20.15,20.15,0,0,1,11,15.26a20.07,20.07,0,0,1-3.17-2.65A5.89,5.89,0,0,1,5.88,8.83,2.45,2.45,0,0,1,8.31,6.36Z"/></g></svg>
        										</span></span><?php esc_html_e('Favourites', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="add_to_queue" data-musicid="<?php esc_attr_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>"><span class="opt_icon"><span class="icon icon_queue">
        											<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
        													<path fill-rule="evenodd" d="M11.359,5.172 L6.847,5.172 L6.847,0.660 C6.847,0.455 6.568,0.009 6.010,0.009 C5.452,0.009 5.172,0.455 5.172,0.660 L5.172,5.172 L0.661,5.172 C0.455,5.172 0.010,5.451 0.010,6.009 C0.010,6.567 0.455,6.846 0.661,6.846 L5.173,6.846 L5.173,11.358 C5.173,11.563 5.452,12.009 6.010,12.009 C6.568,12.009 6.847,11.563 6.847,11.358 L6.847,6.846 L11.359,6.846 C11.564,6.846 12.010,6.567 12.010,6.009 C12.010,5.451 11.564,5.172 11.359,5.172 Z"/>
        													</svg>
        										</span></span><?php esc_html_e('Add To Queue', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="ms_download" data-msmusic="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon icon_dwn">
        											<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_06-4" data-name=" 06-4"><path id="_06-5" data-name=" 06-5" class="cls-1" d="M10.65,13.85a.48.48,0,0,0,.7,0l3.27-3.5a.41.41,0,0,0,.07-.47.48.48,0,0,0-.42-.26H12.4V4.94a.46.46,0,0,0-.47-.44H10.07a.46.46,0,0,0-.47.44V9.63H7.73a.44.44,0,0,0-.42.25.41.41,0,0,0,.07.47Zm5.48-.73v2.63H5.87V13.12H4v3.5a.9.9,0,0,0,.93.88H17.07a.9.9,0,0,0,.93-.88v-3.5Z"/></g></svg>
        										</span></span><?php esc_html_e('Download Now', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="ms_add_playlist" data-msmusic="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon icon_playlst">
        											<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_03-2" data-name=" 03-2"><path id="_03-3" data-name=" 03-3" class="cls-1" d="M13,5.5H3.5V7.07H13V5.5Zm0,3.14H3.5v1.57H13V8.64ZM3.5,13.36H9.82V11.79H3.5ZM14.55,5.5v6.43a2.35,2.35,0,1,0,1.58,2.21V7.07H18.5V5.5Z"/></g></svg>
        										</span></span><?php esc_html_e('Add To Playlist', 'miraculous'); ?></a></li>
                                                <li><a href="javascript:;" class="ms_share_music" data-shareuri="<?php esc_attr_e(get_the_permalink()); ?>" data-sharename="<?php the_title_attribute(); ?>"><span class="opt_icon"><span class="icon icon_share">
        											<svg xmlns="http://www.w3.org/2000/svg" id="Layer_1" data-name="Layer 1" viewBox="0 0 22 22"><g id="_14-2" data-name=" 14-2"><path id="_13" data-name=" 13" class="cls-1" d="M8.68,13.18A2.78,2.78,0,0,1,4.77,13l-.07-.08a3,3,0,0,1,0-3.85,2.77,2.77,0,0,1,3.89-.36.52.52,0,0,1,.11.1l3-2.11.09-.06a1.09,1.09,0,0,0,.63-1.08A2.76,2.76,0,0,1,15.05,3,2.84,2.84,0,0,1,17.9,5.22a3,3,0,0,1-1.36,3.22,2.72,2.72,0,0,1-3.34-.5l-.27-.3C11.81,8.41,10.7,9.18,9.6,10a.37.37,0,0,0-.09.28q0,.75,0,1.5a.51.51,0,0,0,.13.34c1.08.77,2.18,1.52,3.3,2.3a2.89,2.89,0,0,1,1.76-1.15A2.83,2.83,0,0,1,18,15.56h0A2.92,2.92,0,0,1,15.72,19a2.82,2.82,0,0,1-3.28-2.28,3.33,3.33,0,0,1,0-.63.55.55,0,0,0-.16-.38ZM6.82,9.55a1.45,1.45,0,0,0,0,2.9,1.45,1.45,0,0,0,0-2.9ZM15.2,7.36a1.43,1.43,0,0,0,1.39-1.45h0A1.4,1.4,0,1,0,15.2,7.36Zm0,7.29a1.42,1.42,0,0,0-1.4,1.43h0a1.4,1.4,0,0,0,1.44,1.36,1.4,1.4,0,0,0,0-2.8Z"/></g></svg>
        										</span></span><?php esc_html_e('Share', 'miraculous'); ?></a></li>
                                            </ul>
                                        <div class="ms_play_icon play_btn play_music" data-musicid="<?php esc_html_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>">
                                            <img src="<?php echo esc_url($play_img); ?>" alt="<?php echo esc_attr('Play', 'miraculous'); ?>">
                                        </div>
                                    </div>
                                </div>
                                <div class="ms_rcnt_box_text">
                                    <h3><a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a></h3>
                                    <?php $artists_name = array();	 
									if( defined('FW') ){
										$artists_ids = fw_get_db_post_option(get_the_id(), 'music_artists'); 
										
										foreach ($artists_ids as $artists_id) {
											 $artists_name[] = get_the_title($artists_id);
										}
									}
									if ( class_exists( 'ReduxFramework' ) ) {
										$artists_name = array();
										$artists_ids = '';
										$artists_ids = get_post_meta(get_the_id(), 'music_artists');
										foreach ($artists_ids[0] as $artists_id) {
										   $artists_name[] = get_the_title($artists_id);
										}
									}
									?>
                                    <p><?php echo implode(', ', $artists_name); ?></p>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_postdata(); ?>
                </div>
            </div>
        </div>
        <?php endif; 
        if( $settings['style_format'] == 'abstyle2' ): ?>
        <!-- Weekly Top 15 -->
        <div class="ms_weekly_wrapper ms_free_music">
            <div class="ms_weekly_inner">
                <div class="row">
                    <?php if(!empty($settings['track_heading'])){ ?>
                    <div class="col-lg-12">
                        <div class="ms_heading">
                            <h1><?php echo esc_html( $settings['track_heading'] ); ?></h1>
                        </div>
                    </div>
                    <?php 
                    }
        			$i=01; $n = $music_posts->found_posts; $rm = $n%3;
        			while ( $music_posts->have_posts() ) : $music_posts->the_post(); 
        			?>
                        <div class="col-lg-6 col-md-6 cl-sm-12">
                            <div class="ms_weekly_box">
                                <div class="weekly_left">
        						   <span class="w_top_no">
                                        <?php echo (strlen($i) <2) ? '0'.$i : $i; ?>
                                    </span> 
                                    <div class="w_top_song">
        							  <div class="w_tp_song_img">
                                            <?php the_post_thumbnail( 'thumbnail' ); ?>
                                            <div class="ms_song_overlay">
                                            </div>
                                            <div class="ms_play_icon play_btn play_music" data-musicid="<?php esc_html_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>">
                                                <img src="<?php echo esc_url($play_img); ?>" alt="<?php echo esc_attr('Play', 'miraculous'); ?>">
                                            </div>
                                        </div>
                                        <div class="w_tp_song_name">
                                            <h3><a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a></h3>
                                            <?php 
											$artists_name = array();					
											if( defined('FW') ){
												$artists_ids = fw_get_db_post_option(get_the_id(), 'music_artists'); 
												
												foreach ($artists_ids as $artists_id) {
													 $artists_name[] = get_the_title($artists_id);
												}
											}
											if ( class_exists( 'ReduxFramework' ) ) {
												$artists_name = array();
												$artists_ids = '';
												$artists_ids = get_post_meta(get_the_id(), 'music_artists');
												if(!empty($artists_ids)){
													foreach ($artists_ids[0] as $artists_id) {
													   $artists_name[] = get_the_title($artists_id);
													}
												}
											}?>
											
                                            <p><?php echo implode(', ', $artists_name); ?></p>
                                        
										</div>
                                    </div>
                                </div>
                                <?php $attach_meta = array(); $music_price = '';
									if(function_exists('fw_get_db_post_option')){
										$music_extranal_url = get_post_meta(get_the_id(), 'fw_option:music_extranal_url', true);
										
										if(!empty($music_extranal_url)):
											$mpurl = $music_extranal_url;
										else:
											$mpurl = get_post_meta(get_the_id(), 'fw_option:mp3_full_songs', true);
										endif;
									}
									
									if ( class_exists( 'ReduxFramework' ) ) {
										$music_extranal_url = get_post_meta(get_the_id(),'music_extranal_url',true);
										if(!empty($music_extranal_url)):
											$mpurl = $music_extranal_url;
										else:
											$mpurl = get_post_meta(get_the_id(), 'mp3_full_songs', true);
										endif;
									}
                                    if(isset($mpurl['attachment_id'])) {
                                        $attach_meta = wp_get_attachment_metadata( $mpurl['attachment_id'] );
                                    }
                                    $image_uri = get_the_post_thumbnail_url ( get_the_id() );
                                    if(!empty($miraculous_theme_data['miraculous_layout']) && $miraculous_theme_data['miraculous_layout'] == '2'):
                                        $more_img = get_template_directory_uri().'/assets/images/svg/more1.svg';
                                    endif;
									
                                    if(function_exists('fw_get_db_post_option')){
                                        $music_price_arr = fw_get_db_post_option(get_the_id(), 'music_type_options');
                                        if( !empty( $music_price_arr['premium']['single_music_price'] ) ){
                                            $music_price = $music_price_arr['premium']['single_music_price'];
                                        }
                                    }
									
									if ( class_exists( 'ReduxFramework' ) ) {
										$music_price_arr = get_post_meta(get_the_id(), 'music_type_options');
                                        if( !empty( $music_price_arr['premium']['single_music_price'] ) ){
                                            $music_price = $music_price_arr['premium']['single_music_price'];
                                        }
									}
                                    ?>
                                <div class="weekly_right">
                                    <?php
									if( defined('FW') ){
										$duration = fw_get_db_post_option(get_the_ID(), 'music_extranal_url');
									}
									if ( class_exists( 'ReduxFramework' ) ) {
										$duration = get_post_meta(get_the_ID(), 'music_extranal_url');
									}
        				            $data_s = get_post_meta( get_the_ID(), 'fb_gal_ids', true );
                                    ?>
                                    <span class="w_song_time">
                                        <?php
                                        if(!empty($duration)){
                        				echo esc_html($data_s);
                                        }
                        				else{
                            			echo (isset($attach_meta['length_formatted'])) ? $attach_meta['length_formatted'] : "0.00";
                        				}?></span>
                                    
                                   
                                    <span class="w_song_dwnload ms_download" data-msmusic="<?php echo esc_attr(get_the_id()); ?>">
                                        <i class="ms_icon1 dwnload_icon fa fa-download"></i>
                                        <?php 
                                        if( $settings['song_download'] == 'yes'):
                                        if(function_exists('miraculous_song_dowenload_counter')):
                                          miraculous_song_dowenload_counter(get_the_id());
                                        endif;
                                        endif;
                                        ?>
                                    </span>
                                    <span class="w_song_dwnload ">
                                    <?php
                                    if( $settings['song_view'] == 'yes'):
                                    if(function_exists('miraculous_song_view_counter')):
                                        miraculous_song_view_counter(get_the_id());
                                    endif; 
                                    endif;
                                    ?>
                                    </span>
									<span class="like-dislike-buttons">
										<!-- Like Button -->
										<button class="like-btn" data-post-id="<?php the_ID(); ?>">
										<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 64 64" style="enable-background:new 0 0 512 512"  width="20px" height="20px" class="likefill"><g><path d="M59.939 29.958a5.735 5.735 0 0 0-4.89-4.8h-15.29a1 1 0 0 1-.94-1.33 31.427 31.427 0 0 0 1.32-4.57c1.44-5.418.802-9.98-4.02-13.06a4.584 4.584 0 0 0-7 4.01c.014 2.202.52 5.743-.38 7.78a55.92 55.92 0 0 1-5.38 10.73l-1.09 1.17a6.114 6.114 0 0 1 1.1 3.54v20.79a6.329 6.329 0 0 1-.93 3.29 8.148 8.148 0 0 0 3.76 1.01h23.45a5.53 5.53 0 0 0 5.46-4.13 5.15 5.15 0 0 0-.66-3.77 5.116 5.116 0 0 0 2.72-2.71 5.178 5.178 0 0 0-.27-4.51 5.124 5.124 0 0 0 2.74-2.75 5.381 5.381 0 0 0-1.34-5.76 5.75 5.75 0 0 0 1.64-4.93zM17.089 29.138H4.999a1.003 1.003 0 0 0-1 1v27.37a1.003 1.003 0 0 0 1 1h12.09a4.273 4.273 0 0 0 3.72-2.18 4.182 4.182 0 0 0 .56-2.11v-20.79a4.29 4.29 0 0 0-4.28-4.29zM46.499 12.998a4.507 4.507 0 0 1 4.5 4.5 1 1 0 0 0 2 0 4.507 4.507 0 0 1 4.5-4.5 1 1 0 0 0 0-2 4.507 4.507 0 0 1-4.5-4.5 1 1 0 0 0-2 0 4.507 4.507 0 0 1-4.5 4.5 1 1 0 0 0 0 2zM12.499 12.998a4.507 4.507 0 0 1 4.5 4.5 1 1 0 0 0 2 0 4.507 4.507 0 0 1 4.5-4.5 1 1 0 0 0 0-2 4.507 4.507 0 0 1-4.5-4.5 1 1 0 0 0-2 0 4.507 4.507 0 0 1-4.5 4.5 1 1 0 0 0 0 2z" fill="currentColor" opacity="1" data-original="#000000" class=""/></g></svg>
										<span class="like-count">
											<?php echo get_post_meta(get_the_ID(), 'like_count', true) ?: 0; ?>
										</span>
										</button>
										<!-- Dislike Button -->
										<button class="dislike-btn" data-post-id="<?php the_ID(); ?>">
										    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 456.824 456.824" style="enable-background:new 0 0 512 512" width="20px" height="20px" class="dislikefill"><g><path d="M100.5 45.683H18.276c-4.949 0-9.231 1.809-12.851 5.426C1.809 54.724 0 59.007 0 63.954v182.729c0 4.948 1.809 9.233 5.426 12.847 3.616 3.614 7.898 5.425 12.851 5.425H100.5c4.948 0 9.229-1.811 12.847-5.425 3.616-3.613 5.424-7.898 5.424-12.847V63.954c0-4.947-1.809-9.229-5.424-12.845-3.617-3.618-7.898-5.426-12.847-5.426zm-32.835 67.668c-3.616 3.617-7.898 5.424-12.847 5.424-5.14 0-9.471-1.807-12.99-5.424-3.521-3.617-5.281-7.898-5.281-12.85 0-5.137 1.759-9.469 5.281-12.991 3.52-3.521 7.85-5.28 12.99-5.28 4.949 0 9.231 1.759 12.847 5.28 3.621 3.521 5.426 7.854 5.426 12.991 0 4.948-1.809 9.229-5.426 12.85zM441.106 204.141c2.861-8.376 4.281-15.608 4.261-21.693.575-14.466-3.519-27.504-12.279-39.114 3.237-10.66 3.237-21.797 0-33.407-2.847-10.85-7.994-19.792-15.413-26.835 1.711-21.32-2.95-38.543-13.99-51.678-12.183-14.465-30.929-21.892-56.246-22.27H310.61c-12.56 0-26.269 1.475-41.114 4.425-14.838 2.952-26.405 5.713-34.68 8.282-8.28 2.568-19.75 6.328-34.403 11.276-23.413 8.183-38.45 12.371-45.111 12.56-4.949.193-9.231 2.046-12.847 5.569-3.617 3.518-5.426 7.755-5.426 12.703V246.97c0 4.757 1.718 8.898 5.142 12.416 3.424 3.524 7.517 5.476 12.275 5.858 4.565.384 11.799 5.996 21.698 16.844 9.9 10.849 19.511 22.368 28.836 34.551 12.944 16.553 22.558 27.973 28.837 34.256 3.424 3.422 6.37 7.99 8.848 13.702 2.472 5.708 4.142 10.324 5.004 13.846.855 3.519 2.135 9.274 3.856 17.275 1.328 7.419 2.519 13.227 3.569 17.412 1.047 4.188 2.898 9.137 5.564 14.845 2.67 5.716 5.903 10.469 9.712 14.274 3.614 3.62 7.898 5.431 12.847 5.431 8.761 0 16.604-.999 23.559-2.998 6.947-1.998 12.655-4.469 17.131-7.419 4.477-2.957 8.282-6.803 11.424-11.566 3.142-4.757 5.424-9.042 6.851-12.848 1.431-3.812 2.574-8.562 3.426-14.27.855-5.716 1.338-10 1.431-12.854.093-2.854.144-6.563.144-11.136 0-7.228-.948-14.51-2.851-21.84-1.909-7.323-3.72-12.895-5.428-16.707-1.711-3.806-4.281-9.227-7.706-16.269-.575-1.144-1.523-2.861-2.854-5.144-1.328-2.283-2.382-4.381-3.142-6.283-.763-1.902-1.522-4.186-2.279-6.852h79.086c14.843 0 27.645-5.428 38.397-16.279 10.756-10.848 16.228-23.694 16.419-38.54-.014-16.744-5.25-30.925-15.719-42.534z" fill="currentColor" opacity="1" data-original="#000000" class=""/></g></svg>
										<span class="dislike-count">
											<?php echo get_post_meta(get_the_ID(), 'dislike_count', true) ?: 0; ?>
										</span>
										</button>
									</span>
									 <span class="ms_more_icon" data-other="1">
                                        <img src="<?php echo esc_url($more_img); ?>" alt="<?php echo esc_attr('More', 'miraculous'); ?>">                                
                                    </span>
                                </div>
                                <?php
                                $fav_class = 'icon_fav';
                                if(!empty($fav_music_ids)){
                                    if(in_array(get_the_id(), $fav_music_ids) ) {
        			                    $fav_class = 'icon_fav_add';
        		      	            }
                                }
                                ?>
                                <ul class="more_option">
                                    <li><a href="javascript:;" class="favourite_music" data-musicid="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon <?php echo esc_attr($fav_class); ?>">
        								<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_08-5" data-name=" 08-5"><path id="_08-6" data-name=" 08-6" class="cls-1" d="M13.7,4.49a4.34,4.34,0,0,0-2,.48,3.83,3.83,0,0,0-.73.48A3.54,3.54,0,0,0,10.27,5,4.3,4.3,0,0,0,4,8.83a7.6,7.6,0,0,0,2.46,5.05,22.38,22.38,0,0,0,4,3.29l.51.34.52-.34a23.09,23.09,0,0,0,4-3.29A7.63,7.63,0,0,0,18,8.83,4.34,4.34,0,0,0,13.7,4.49ZM8.31,6.36a2.42,2.42,0,0,1,1.94,1l.75,1,.76-1a2.39,2.39,0,0,1,1.94-1,2.45,2.45,0,0,1,2.43,2.47,5.89,5.89,0,0,1-1.95,3.78A20.15,20.15,0,0,1,11,15.26a20.07,20.07,0,0,1-3.17-2.65A5.89,5.89,0,0,1,5.88,8.83,2.45,2.45,0,0,1,8.31,6.36Z"/></g></svg>
        							</span></span><?php esc_html_e('Favourites', 'miraculous'); ?></a></li>
                                    <li><a href="javascript:;" class="add_to_queue" data-musicid="<?php esc_attr_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>"><span class="opt_icon"><span class="icon icon_queue">
        								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
        										<path fill-rule="evenodd" d="M11.359,5.172 L6.847,5.172 L6.847,0.660 C6.847,0.455 6.568,0.009 6.010,0.009 C5.452,0.009 5.172,0.455 5.172,0.660 L5.172,5.172 L0.661,5.172 C0.455,5.172 0.010,5.451 0.010,6.009 C0.010,6.567 0.455,6.846 0.661,6.846 L5.173,6.846 L5.173,11.358 C5.173,11.563 5.452,12.009 6.010,12.009 C6.568,12.009 6.847,11.563 6.847,11.358 L6.847,6.846 L11.359,6.846 C11.564,6.846 12.010,6.567 12.010,6.009 C12.010,5.451 11.564,5.172 11.359,5.172 Z"/>
        										</svg>
        							</span></span><?php esc_html_e('Add To Queue', 'miraculous'); ?></a></li>
                                    <li><a href="javascript:;" class="ms_download" data-msmusic="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon icon_dwn">
        								<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_06-4" data-name=" 06-4"><path id="_06-5" data-name=" 06-5" class="cls-1" d="M10.65,13.85a.48.48,0,0,0,.7,0l3.27-3.5a.41.41,0,0,0,.07-.47.48.48,0,0,0-.42-.26H12.4V4.94a.46.46,0,0,0-.47-.44H10.07a.46.46,0,0,0-.47.44V9.63H7.73a.44.44,0,0,0-.42.25.41.41,0,0,0,.07.47Zm5.48-.73v2.63H5.87V13.12H4v3.5a.9.9,0,0,0,.93.88H17.07a.9.9,0,0,0,.93-.88v-3.5Z"/></g></svg>
        							</span></span><?php esc_html_e('Download Now', 'miraculous'); ?></a></li>
                                    <li><a href="javascript:;" class="ms_add_playlist" data-msmusic="<?php echo esc_attr(get_the_id()); ?>"><span class="opt_icon"><span class="icon icon_playlst">
        								<svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_03-2" data-name=" 03-2"><path id="_03-3" data-name=" 03-3" class="cls-1" d="M13,5.5H3.5V7.07H13V5.5Zm0,3.14H3.5v1.57H13V8.64ZM3.5,13.36H9.82V11.79H3.5ZM14.55,5.5v6.43a2.35,2.35,0,1,0,1.58,2.21V7.07H18.5V5.5Z"/></g></svg>
        							</span></span><?php esc_html_e('Add To Playlist', 'miraculous'); ?></a></li>
                                    <li><a href="javascript:;" class="ms_share_music" data-shareuri="<?php esc_attr_e(get_the_permalink()); ?>" data-sharename="<?php the_title_attribute(); ?>"><span class="opt_icon"><span class="icon icon_share">
        								<svg xmlns="http://www.w3.org/2000/svg" id="Layer_1" data-name="Layer 1" viewBox="0 0 22 22"><g id="_14-2" data-name=" 14-2"><path id="_13" data-name=" 13" class="cls-1" d="M8.68,13.18A2.78,2.78,0,0,1,4.77,13l-.07-.08a3,3,0,0,1,0-3.85,2.77,2.77,0,0,1,3.89-.36.52.52,0,0,1,.11.1l3-2.11.09-.06a1.09,1.09,0,0,0,.63-1.08A2.76,2.76,0,0,1,15.05,3,2.84,2.84,0,0,1,17.9,5.22a3,3,0,0,1-1.36,3.22,2.72,2.72,0,0,1-3.34-.5l-.27-.3C11.81,8.41,10.7,9.18,9.6,10a.37.37,0,0,0-.09.28q0,.75,0,1.5a.51.51,0,0,0,.13.34c1.08.77,2.18,1.52,3.3,2.3a2.89,2.89,0,0,1,1.76-1.15A2.83,2.83,0,0,1,18,15.56h0A2.92,2.92,0,0,1,15.72,19a2.82,2.82,0,0,1-3.28-2.28,3.33,3.33,0,0,1,0-.63.55.55,0,0,0-.16-.38ZM6.82,9.55a1.45,1.45,0,0,0,0,2.9,1.45,1.45,0,0,0,0-2.9ZM15.2,7.36a1.43,1.43,0,0,0,1.39-1.45h0A1.4,1.4,0,1,0,15.2,7.36Zm0,7.29a1.42,1.42,0,0,0-1.4,1.43h0a1.4,1.4,0,0,0,1.44,1.36,1.4,1.4,0,0,0,0-2.8Z"/></g></svg>
        							</span></span><?php esc_html_e('Share', 'miraculous'); ?></a></li>
                                </ul>
                            </div>
                            <?php if($rm == 0){
                                if($i > $n-3){
                                    
                                }else{
                                    echo '<div class="ms_divider"></div>';
                                }
                                }elseif($rm == 2 && $i > $n-2){
                                    
                                }elseif($rm == 1 && $i > $n-1){
                                    
                                }else{
                                    echo '<div class="ms_divider"></div>';
                                }
                            ?>
                        </div>
                    <?php $i++;
        			endwhile; 
                    wp_reset_postdata(); ?>
                </div>
            </div>
        </div>
        <?php endif; 
        if( $settings['style_format'] == 'abstyle4' ): ?>
        <!-- New Releases Section Start -->
        <div class="ms_releases_wrapper">
            <?php if(!empty($settings['track_heading'])){ ?>
            <div class="ms_heading">
                <h1><?php echo esc_html( $settings['track_heading'] ); ?></h1>
            </div>
            <?php } ?>
            <div class="ms_release_slider swiper-container">
                <div class="ms_divider"></div>
                <div class="swiper-wrapper">
                    <?php while ( $music_posts->have_posts() ) : $music_posts->the_post(); ?>
                        <div class="swiper-slide">
                            <div class="ms_release_box">
                                <div class="w_top_song">
                                    <span class="slider_dot"></span>
                                    <div class="w_tp_song_img">
                                        <?php the_post_thumbnail( 'thumbnail' ); ?>
                                        <div class="ms_song_overlay">
                                        </div>
                                        <div class="ms_play_icon play_btn play_music" data-musicid="<?php esc_attr_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>">
                                            <img src="<?php echo esc_url($play_img); ?>" alt="<?php echo esc_attr('play', 'miraculous'); ?>">
                                        </div>
                                    </div>
                                    <div class="w_tp_song_name">
                                        <h3><a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a></h3>
                                        <?php $artists_name = array(); 
										if( defined('FW') ){
											$artists_ids = fw_get_db_post_option(get_the_id(), 'music_artists'); 
											
											foreach ($artists_ids as $artists_id) {
												 $artists_name[] = get_the_title($artists_id);
											}
										}
										if ( class_exists( 'ReduxFramework' ) ) {
											$artists_name = array();
											$artists_ids = '';
											$artists_ids = get_post_meta(get_the_id(), 'music_artists');
											foreach ($artists_ids[0] as $artists_id) {
											   $artists_name[] = get_the_title($artists_id);
											}
										} ?>
                                        <p><?php echo implode(', ', $artists_name); ?></p>
                                    </div>
                                </div>
                                <?php $attach_meta = array();
								
                                    if(function_exists('fw_get_db_post_option')){
										$music_extranal_url = get_post_meta(get_the_id(), 'fw_option:music_extranal_url', true);
										
										if(!empty($music_extranal_url)):
											$mpurl = $music_extranal_url;
										else:
											$mpurl = get_post_meta(get_the_id(), 'fw_option:mp3_full_songs', true);
										endif;
									}

									if ( class_exists( 'ReduxFramework' ) ) {
										$music_extranal_url = get_post_meta(get_the_id(),'music_extranal_url',true);
										if(!empty($music_extranal_url)):
											$mpurl = $music_extranal_url;
										else:
											$mpurl = get_post_meta(get_the_id(), 'mp3_full_songs', true);
										endif;
									}
									
                                    if(isset($mpurl['attachment_id'])) {
                                        $attach_meta = wp_get_attachment_metadata( $mpurl['attachment_id'] );
                                    }
                                    ?>
                                <div class="weekly_right">
                                    <span class="w_song_time"><?php echo (isset($attach_meta['length_formatted'])) ? $attach_meta['length_formatted'] : "0.00"; ?></span>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_postdata(); ?>
                </div>
            </div>
            <!-- Add Arrows -->
            <div class="swiper-button-next2 swiper-button-next-elementor" tabindex="0" role="button" aria-label="<?php esc_attr_e('Next slide','miraculous'); ?>">
        	    <svg xmlns="http://www.w3.org/2000/svg" version="1.1" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" width="512" height="512" x="0" y="0" viewBox="0 0 128 128" style="enable-background:new 0 0 512 512" xml:space="preserve" class=""><g><path xmlns="http://www.w3.org/2000/svg" id="Down_Arrow_3_" d="m64 88c-1.023 0-2.047-.391-2.828-1.172l-40-40c-1.563-1.563-1.563-4.094 0-5.656s4.094-1.563 5.656 0l37.172 37.172 37.172-37.172c1.563-1.563 4.094-1.563 5.656 0s1.563 4.094 0 5.656l-40 40c-.781.781-1.805 1.172-2.828 1.172z" data-original="#000000" class=""></path></g></svg>
        	</div>
        
        	<div class="swiper-button-prev2 swiper-button-prev-elementor" tabindex="0" role="button" aria-label="<?php esc_attr_e('Previous slide','miraculous'); ?>">
            	<svg xmlns="http://www.w3.org/2000/svg" version="1.1" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" width="512" height="512" x="0" y="0" viewBox="0 0 128 128" style="enable-background:new 0 0 512 512" xml:space="preserve" class=""><g><path xmlns="http://www.w3.org/2000/svg" id="Down_Arrow_3_" d="m64 88c-1.023 0-2.047-.391-2.828-1.172l-40-40c-1.563-1.563-1.563-4.094 0-5.656s4.094-1.563 5.656 0l37.172 37.172 37.172-37.172c1.563-1.563 4.094-1.563 5.656 0s1.563 4.094 0 5.656l-40 40c-.781.781-1.805 1.172-2.828 1.172z" data-original="#000000" class=""></path></g></svg>
        	</div>
        </div>
        <?php endif; 
        if( $settings['style_format'] == 'abstyle5' ): ?>
            <?php if(!empty($settings['track_heading'])){ ?>
            <h2 class="music_listwrap_tttl"><?php echo esc_html( $settings['track_heading'] ); ?></h2>
            <?php } ?>
            <div class="music_listwrap">
                <div class="ms_songslist_box">
                    <ul class="ms_songlist">
                        <?php 
                        $i=1; 
                        while ( $music_posts->have_posts() ) : $music_posts->the_post();
                        ?>
                        <li>
                            <div class="ms_songslist_inner">
                                <div class="ms_songslist_left">
                                    <div class="songslist_number play_btn play_music" data-musicid="<?php esc_html_e(get_the_id()); ?>" data-musictype="<?php printf($list_type); ?>">
                                        <h4 class="songslist_sn"><?php echo (strlen($i) <2) ? '0'.$i : $i; ?></h4>
                                        <span class="songslist_play"><img src="<?php echo esc_url($play_img); ?>" alt="Play" class="img-fluid"/></span>
                                    </div> 
                                    <div class="songslist_details">
                                        <div class="songslist_thumb">
                                            <?php the_post_thumbnail( 'large' ); ?>
                                        </div>
                                        <div class="songslist_name">
                                            
                                            <h3 class="song_name"><a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a></h3>
                                            <?php $artists_name = array(); 
											if( defined('FW') ){
												$artists_ids = fw_get_db_post_option(get_the_id(), 'music_artists'); 
												
												foreach ($artists_ids as $artists_id) {
													 $artists_name[] = get_the_title($artists_id);
												}
											}
											if ( class_exists( 'ReduxFramework' ) ) {
												$artists_name = array();
												$artists_ids = '';
												$artists_ids = get_post_meta(get_the_id(), 'music_artists');
												foreach ($artists_ids[0] as $artists_id) {
												   $artists_name[] = get_the_title($artists_id);
												}
											} ?>
                                            <p class="song_artist"><?php echo implode(', ', $artists_name); ?></p>
                                        </div> 
                                    </div> 
                                </div>
                                <div class="ms_songslist_right">
                                    <span class="ms_songslist_like">
                                        <?php
                                            $fav_class = 'icon_fav';
                                            if(!empty($fav_music_ids)){
                                               if(in_array(get_the_id(), $fav_music_ids) ) {
                                                    $fav_class = 'icon_fav_add';
                                                  }
                                            }
                                        ?>
                                        <a href="javascript:;" class="favourite_music" data-musicid="<?php echo esc_attr(get_the_id()); ?>">
                                            <span class="opt_icon"><span class="icon <?php echo esc_attr($fav_class); ?>"><svg xmlns:xlink="http://www.w3.org/1999/xlink" width="17px" height="16px"><path fill-rule="evenodd" d="M11.777,-0.000 C10.940,-0.000 10.139,0.197 9.395,0.585 C9.080,0.749 8.783,0.947 8.506,1.173 C8.230,0.947 7.931,0.749 7.618,0.585 C6.874,0.197 6.073,-0.000 5.236,-0.000 C2.354,-0.000 0.009,2.394 0.009,5.337 C0.009,7.335 1.010,9.428 2.986,11.557 C4.579,13.272 6.527,14.702 7.881,15.599 L8.506,16.012 L9.132,15.599 C10.487,14.701 12.436,13.270 14.027,11.557 C16.002,9.428 17.004,7.335 17.004,5.337 C17.004,2.394 14.659,-0.000 11.777,-0.000 ZM5.236,2.296 C6.168,2.296 7.027,2.738 7.590,3.507 L8.506,4.754 L9.423,3.505 C9.986,2.737 10.844,2.296 11.777,2.296 C13.403,2.296 14.727,3.660 14.727,5.337 C14.727,6.734 13.932,8.298 12.364,9.986 C11.114,11.332 9.604,12.490 8.506,13.255 C7.409,12.490 5.899,11.332 4.649,9.986 C3.081,8.298 2.286,6.734 2.286,5.337 C2.286,3.660 3.610,2.296 5.236,2.296 Z"/></svg></span>
                                            </span>
                                        </a>
                                    </span>
                                    <?php $attach_meta = array();
									
                                        if(function_exists('fw_get_db_post_option')){
											$music_extranal_url = get_post_meta(get_the_id(), 'fw_option:music_extranal_url', true);
											
											if(!empty($music_extranal_url)):
												$mpurl = $music_extranal_url;
											else:
												$mpurl = get_post_meta(get_the_id(), 'fw_option:mp3_full_songs', true);
											endif;
										}

										if ( class_exists( 'ReduxFramework' ) ) {
											$music_extranal_url = get_post_meta(get_the_id(),'music_extranal_url',true);
											if(!empty($music_extranal_url)):
												$mpurl = $music_extranal_url;
											else:
												$mpurl = get_post_meta(get_the_id(), 'mp3_full_songs', true);
											endif;
										}
										
                                    ?>
                                    <span class="ms_songslist_time"><?php echo (isset($attach_meta['length_formatted'])) ? $attach_meta['length_formatted'] : "0.00"; ?></span>
                                    <div class="ms_songslist_more">
                                        <span class="songslist_moreicon"><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><path fill-rule="evenodd" d="M2.000,12.000 C0.895,12.000 -0.000,11.105 -0.000,10.000 C-0.000,8.895 0.895,8.000 2.000,8.000 C3.104,8.000 4.000,8.895 4.000,10.000 C4.000,11.105 3.104,12.000 2.000,12.000 ZM2.000,4.000 C0.895,4.000 -0.000,3.105 -0.000,2.000 C-0.000,0.895 0.895,-0.000 2.000,-0.000 C3.104,-0.000 4.000,0.895 4.000,2.000 C4.000,3.105 3.104,4.000 2.000,4.000 ZM2.000,16.000 C3.104,16.000 4.000,16.895 4.000,18.000 C4.000,19.105 3.104,20.000 2.000,20.000 C0.895,20.000 -0.000,19.105 -0.000,18.000 C-0.000,16.895 0.895,16.000 2.000,16.000 Z"/></svg></span>
                                        <ul class="ms_common_dropdown ms_songslist_dropdown">
                                            <li>
                                                <a href="javascript:;" class="favourite_music" data-musicid="<?php echo esc_attr(get_the_id()); ?>">
                                                    <span class="common_drop_icon drop_fav"><span class="icon <?php echo esc_attr($fav_class); ?>">
                                                        <svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_08-5" data-name=" 08-5"><path id="_08-6" data-name=" 08-6" class="cls-1" d="M13.7,4.49a4.34,4.34,0,0,0-2,.48,3.83,3.83,0,0,0-.73.48A3.54,3.54,0,0,0,10.27,5,4.3,4.3,0,0,0,4,8.83a7.6,7.6,0,0,0,2.46,5.05,22.38,22.38,0,0,0,4,3.29l.51.34.52-.34a23.09,23.09,0,0,0,4-3.29A7.63,7.63,0,0,0,18,8.83,4.34,4.34,0,0,0,13.7,4.49ZM8.31,6.36a2.42,2.42,0,0,1,1.94,1l.75,1,.76-1a2.39,2.39,0,0,1,1.94-1,2.45,2.45,0,0,1,2.43,2.47,5.89,5.89,0,0,1-1.95,3.78A20.15,20.15,0,0,1,11,15.26a20.07,20.07,0,0,1-3.17-2.65A5.89,5.89,0,0,1,5.88,8.83,2.45,2.45,0,0,1,8.31,6.36Z"></path></g></svg>
                                                    </span></span><?php esc_html_e('Favourites', 'miraculous'); ?></a>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="javascript:;" class="ms_download" data-msmusic="<?php echo esc_attr(get_the_id()); ?>">
                                                    <span class="common_drop_icon drop_downld">
                                                        <svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_06-4" data-name=" 06-4"><path id="_06-5" data-name=" 06-5" class="cls-1" d="M10.65,13.85a.48.48,0,0,0,.7,0l3.27-3.5a.41.41,0,0,0,.07-.47.48.48,0,0,0-.42-.26H12.4V4.94a.46.46,0,0,0-.47-.44H10.07a.46.46,0,0,0-.47.44V9.63H7.73a.44.44,0,0,0-.42.25.41.41,0,0,0,.07.47Zm5.48-.73v2.63H5.87V13.12H4v3.5a.9.9,0,0,0,.93.88H17.07a.9.9,0,0,0,.93-.88v-3.5Z"></path></g></svg>
                                                    </span><?php esc_html_e('Download Now', 'miraculous'); ?>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="javascript:;" class="ms_add_playlist" data-msmusic="<?php echo esc_attr(get_the_id()); ?>">
                                                    <span class="common_drop_icon drop_playlist">
                                                        <svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 22 22"><g id="_03-2" data-name=" 03-2"><path id="_03-3" data-name=" 03-3" class="cls-1" d="M13,5.5H3.5V7.07H13V5.5Zm0,3.14H3.5v1.57H13V8.64ZM3.5,13.36H9.82V11.79H3.5ZM14.55,5.5v6.43a2.35,2.35,0,1,0,1.58,2.21V7.07H18.5V5.5Z"></path></g></svg>
                                                    </span><?php esc_html_e('Add To Playlist', 'miraculous'); ?>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="javascript:;" class="ms_share_music" data-shareuri="<?php esc_attr_e(get_the_permalink()); ?>" data-sharename="<?php the_title_attribute(); ?>">
                                                    <span class="common_drop_icon drop_share">
                                                        <svg xmlns="http://www.w3.org/2000/svg" id="Layer_1" data-name="Layer 1" viewBox="0 0 22 22"><g id="_14-2" data-name=" 14-2"><path id="_13" data-name=" 13" class="cls-1" d="M8.68,13.18A2.78,2.78,0,0,1,4.77,13l-.07-.08a3,3,0,0,1,0-3.85,2.77,2.77,0,0,1,3.89-.36.52.52,0,0,1,.11.1l3-2.11.09-.06a1.09,1.09,0,0,0,.63-1.08A2.76,2.76,0,0,1,15.05,3,2.84,2.84,0,0,1,17.9,5.22a3,3,0,0,1-1.36,3.22,2.72,2.72,0,0,1-3.34-.5l-.27-.3C11.81,8.41,10.7,9.18,9.6,10a.37.37,0,0,0-.09.28q0,.75,0,1.5a.51.51,0,0,0,.13.34c1.08.77,2.18,1.52,3.3,2.3a2.89,2.89,0,0,1,1.76-1.15A2.83,2.83,0,0,1,18,15.56h0A2.92,2.92,0,0,1,15.72,19a2.82,2.82,0,0,1-3.28-2.28,3.33,3.33,0,0,1,0-.63.55.55,0,0,0-.16-.38ZM6.82,9.55a1.45,1.45,0,0,0,0,2.9,1.45,1.45,0,0,0,0-2.9ZM15.2,7.36a1.43,1.43,0,0,0,1.39-1.45h0A1.4,1.4,0,1,0,15.2,7.36Zm0,7.29a1.42,1.42,0,0,0-1.4,1.43h0a1.4,1.4,0,0,0,1.44,1.36,1.4,1.4,0,0,0,0-2.8Z"></path></g></svg>
                                                    </span><?php esc_html_e('Share', 'miraculous'); ?>
                                                </a>
                                             </li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </li>
                        <?php $i++; endwhile; ?>
                        <?php wp_reset_postdata(); ?>
                    </ul>
                </div>
            </div>
        <?php endif;
        endif; 
	}
}
